@@ -36,8 +36,6 @@ def heatclient(request, password=None):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
     endpoint = base.url_for(request, 'orchestration')
-    LOG.debug('heatclient connection created using token "%s" and url "%s"' %
-              (request.user.token.id, endpoint))
     kwargs = {
         'token': request.user.token.id,
         'insecure': insecure,
@@ -104,10 +102,12 @@ def stack_create(request, password=None, **kwargs):
     return heatclient(request, password).stacks.create(**kwargs)
 
 
-def stack_update(request, stack_id, **kwargs):
-    if kwargs.get('password'):
-        kwargs.pop('password')
-    return heatclient(request).stacks.update(stack_id, **kwargs)
+def stack_preview(request, password=None, **kwargs):
+    return heatclient(request, password).stacks.preview(**kwargs)
+
+
+def stack_update(request, stack_id, password=None, **kwargs):
+    return heatclient(request, password).stacks.update(stack_id, **kwargs)
 
 
 def events_list(request, stack_name):
@@ -128,3 +128,27 @@ def resource_metadata_get(request, stack_id, resource_name):
 
 def template_validate(request, **kwargs):
     return heatclient(request).stacks.validate(**kwargs)
+
+
+def action_check(request, stack_id):
+    return heatclient(request).actions.check(stack_id)
+
+
+def action_suspend(request, stack_id):
+    return heatclient(request).actions.suspend(stack_id)
+
+
+def action_resume(request, stack_id):
+    return heatclient(request).actions.resume(stack_id)
+
+
+def resource_types_list(request):
+    return heatclient(request).resource_types.list()
+
+
+def resource_type_get(request, resource_type):
+    return heatclient(request).resource_types.get(resource_type)
+
+
+def service_list(request):
+    return heatclient(request).services.list()
