@@ -11,31 +11,22 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""API over the keystone service."""
+"""API over the keystone service.
+"""
 
-from django.conf import settings
 import django.http
 from django.views import generic
 
 from openstack_dashboard import api
-from openstack_dashboard.api.rest import urls
 from openstack_dashboard.api.rest import utils as rest_utils
 
-
-@urls.register
-class Version(generic.View):
-    """API for active keystone version."""
-    url_regex = r'keystone/version/$'
-
-    @rest_utils.ajax()
-    def get(self, request):
-        """Get active keystone version."""
-        return {'version': str(api.keystone.get_version())}
+from openstack_dashboard.api.rest import urls
 
 
 @urls.register
 class Users(generic.View):
-    """API for keystone users."""
+    """API for keystone users.
+    """
     url_regex = r'keystone/users/$'
     client_keywords = {'project_id', 'domain_id', 'group_id'}
 
@@ -71,25 +62,32 @@ class Users(generic.View):
 
         Create a user using the parameters supplied in the POST
         application/json object. The base parameters are name (string), email
-        (string, optional), password (string), project (string,
-        optional), enabled (boolean, defaults to true), description
-        (string, optional). The user will be created in the default domain.
+        (string, optional), password (string, optional), project_id (string,
+        optional), enabled (boolean, defaults to true). The user will be
+        created in the default domain.
 
         This action returns the new user object on success.
         """
+        # not sure why email is forced to None, but other code does it
         domain = api.keystone.get_default_domain(request)
-
         new_user = api.keystone.user_create(
             request,
             name=request.DATA['name'],
             email=request.DATA.get('email') or None,
             password=request.DATA.get('password'),
-            project=request.DATA.get('project') or None,
-            enabled=request.DATA.get('enabled', True),
-            description=request.DATA.get('description') or None,
+            project=request.DATA.get('project_id'),
+            enabled=True,
             domain=domain.id
         )
 
+        # assign role to user
+        api.keystone.add_tenant_user_role(
+            request,
+            project=request.DATA.get('project_id'),
+            user=new_user.id,
+            role=request.DATA.get('role_id')
+        )
+
         return rest_utils.CreatedResponse(
             '/api/keystone/users/%s' % new_user.id,
             new_user.to_dict()
@@ -111,7 +109,8 @@ class Users(generic.View):
 
 @urls.register
 class User(generic.View):
-    """API for a single keystone user."""
+    """API for a single keystone user.
+    """
     url_regex = r'keystone/users/(?P<id>[0-9a-f]+|current)$'
 
     @rest_utils.ajax()
@@ -153,11 +152,6 @@ class User(generic.View):
         user = api.keystone.user_get(request, id)
 
         if 'password' in keys:
-            if getattr(settings, 'ENFORCE_PASSWORD_CHECK', False):
-                admin_password = request.DATA['admin_password']
-                if not api.keystone.user_verify_admin_password(request,
-                                                               admin_password):
-                    raise rest_utils.AjaxError(400, 'ADMIN_PASSWORD_INCORRECT')
             password = request.DATA['password']
             api.keystone.user_update_password(request, user, password)
 
@@ -174,7 +168,8 @@ class User(generic.View):
 
 @urls.register
 class Roles(generic.View):
-    """API over all roles."""
+    """API over all roles.
+    """
     url_regex = r'keystone/roles/$'
 
     @rest_utils.ajax()
@@ -231,7 +226,8 @@ class Roles(generic.View):
 
 @urls.register
 class Role(generic.View):
-    """API for a single role."""
+    """API for a single role.
+    """
     url_regex = r'keystone/roles/(?P<id>[0-9a-f]+|default)$'
 
     @rest_utils.ajax()
@@ -267,20 +263,10 @@ class Role(generic.View):
         api.keystone.role_update(request, id, request.DATA['name'])
 
 
-@urls.register
-class DefaultDomain(generic.View):
-    """API for default domain of the user."""
-    url_regex = r'keystone/default_domain/$'
-
-    @rest_utils.ajax()
-    def get(self, request):
-        """Get a default domain of the user."""
-        return api.keystone.get_default_domain(request).to_dict()
-
-
 @urls.register
 class Domains(generic.View):
-    """API over all domains."""
+    """API over all domains.
+    """
     url_regex = r'keystone/domains/$'
 
     @rest_utils.ajax()
@@ -331,7 +317,8 @@ class Domains(generic.View):
 
 @urls.register
 class Domain(generic.View):
-    """API over a single domains."""
+    """API over a single domains.
+    """
     url_regex = r'keystone/domains/(?P<id>[0-9a-f]+|default)$'
 
     @rest_utils.ajax()
@@ -420,16 +407,13 @@ class Projects(generic.View):
         if len(filters) == 0:
             filters = None
 
-        paginate = request.GET.get('paginate') == 'true'
-        admin = False if request.GET.get('admin') == 'false' else True
-
         result, has_more = api.keystone.tenant_list(
             request,
-            paginate=paginate,
+            paginate=request.GET.get('paginate', False),
             marker=request.GET.get('marker'),
             domain=request.GET.get('domain_id'),
             user=request.GET.get('user_id'),
-            admin=admin,
+            admin=request.GET.get('admin', True),
             filters=filters
         )
         # return (list of results, has_more_data)
@@ -486,7 +470,8 @@ class Project(generic.View):
 
     @rest_utils.ajax()
     def get(self, request, id):
-        """Get a specific project by id."""
+        """Get a specific project by id.
+        """
         return api.keystone.tenant_get(request, id).to_dict()
 
     @rest_utils.ajax()
@@ -516,7 +501,7 @@ class Project(generic.View):
 @urls.register
 class ProjectRole(generic.View):
     url_regex = r'keystone/projects/(?P<project_id>[0-9a-f]+)/' \
-                '(?P<role_id>[0-9a-f]+)/(?P<user_id>[0-9a-f]+)$'
+                ' (?P<role_id>[0-9a-f]+)/(?P<user_id>[0-9a-f]+)$'
 
     @rest_utils.ajax()
     def put(self, request, project_id, role_id, user_id):
@@ -540,13 +525,16 @@ class ServiceCatalog(generic.View):
 
     @rest_utils.ajax()
     def get(self, request):
-        """Return the service catalog associated with the current user."""
+        """Return the Keystone service catalog associated with the current
+        user.
+        """
         return request.user.service_catalog
 
 
 @urls.register
 class UserSession(generic.View):
-    """API for a single keystone user."""
+    """API for a single keystone user.
+    """
     url_regex = r'keystone/user-session/$'
     allowed_fields = {
         'available_services_regions',
@@ -566,110 +554,6 @@ class UserSession(generic.View):
 
     @rest_utils.ajax()
     def get(self, request):
-        """Get the current user session."""
-        res = {k: getattr(request.user, k, None) for k in self.allowed_fields}
-        if getattr(settings, 'ENABLE_CLIENT_TOKEN', True):
-            res['token'] = request.user.token.id
-        return res
-
-
-@urls.register
-class Services(generic.View):
-    """API for keystone services."""
-    url_regex = r'keystone/services/$'
-
-    @rest_utils.ajax()
-    def get(self, request):
-        """Get a list of keystone services."""
-        region = request.user.services_region
-        services = []
-        for i, service in enumerate(request.user.service_catalog):
-            services.append(
-                dict(api.keystone.Service(service, region).to_dict(), id=i)
-            )
-
-        return {'items': services}
-
-
-@urls.register
-class Groups(generic.View):
-    """API over all groups."""
-    url_regex = r'keystone/groups/$'
-
-    @rest_utils.ajax()
-    def get(self, request):
-        """Get a list of groups.
-
-        The listing result is an object with property "items".
+        """Get the current user session.
         """
-        domain_context = request.session.get('domain_context')
-        items = [d.to_dict() for d in api.keystone.group_list(
-            request, domain=request.GET.get('domain_id', domain_context))]
-
-        return {'items': items}
-
-    @rest_utils.ajax(data_required=True)
-    def post(self, request):
-        """Create a group.
-
-        This action creates a group using parameters supplied in the POST
-        application/json object. The "name" (string) parameter is required,
-        "description" (string) is optional.
-
-        This method returns the new group object on success.
-        """
-        domain_context = request.session.get('domain_context')
-        new_group = api.keystone.group_create(
-            request,
-            request.GET.get('domain_id', domain_context),
-            request.DATA['name'],
-            request.DATA.get("description", None))
-
-        return rest_utils.CreatedResponse(
-            '/api/keystone/groups/%s' % new_group.id,
-            new_group.to_dict()
-        )
-
-    @rest_utils.ajax(data_required=True)
-    def delete(self, request):
-        """Delete multiple groups by id.
-
-        The DELETE data should be an application/json array of group ids to
-        delete.
-
-        This method returns HTTP 204 (no content) on success.
-        """
-        for group_id in request.DATA:
-            api.keystone.group_delete(request, group_id)
-
-
-@urls.register
-class Group(generic.View):
-    """API over a single group."""
-    url_regex = r'keystone/groups/(?P<id>[0-9a-f]+)$'
-
-    @rest_utils.ajax()
-    def get(self, request, id):
-        """Get a specific group by id."""
-        return api.keystone.group_get(request, id).to_dict()
-
-    @rest_utils.ajax()
-    def delete(self, request, id):
-        """Delete a single group by id.
-
-        This method returns HTTP 204 (no content) on success.
-        """
-        api.keystone.group_delete(request, id)
-
-    @rest_utils.ajax(data_required=True)
-    def patch(self, request, id):
-        """Update a single group.
-
-        The PATCH data should be an application/json object with the
-        "name" and "description" attribute to update.
-
-        This method returns HTTP 204 (no content) on success.
-        """
-        api.keystone.group_update(request, id,
-                                  request.DATA['name'],
-                                  request.DATA.get("description", None))
+        return {k: getattr(request.user, k, None) for k in self.allowed_fields}
