@@ -12,20 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.dashboards.admin import dashboard
+
 
 class Networks(horizon.Panel):
     name = _("Networks")
     slug = 'networks'
     permissions = ('openstack.services.network',)
-    policy_rules = (("network", "context_is_admin"),)
 
-    def allowed(self, context):
-        if (('network' in settings.SYSTEM_SCOPE_SERVICES) !=
-                bool(context['request'].user.system_scoped)):
-            return False
-        return super().allowed(context)
+dashboard.Admin.register(Networks)
