@@ -15,16 +15,14 @@
 import logging
 
 from django.conf import settings
-from django import shortcuts
+from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
-from django.urls import reverse
 from django.utils.http import urlencode
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
-from keystoneclient import exceptions as keystoneclient_exceptions
+from keystoneclient import exceptions
 
-from horizon import exceptions
 from horizon import messages
 from horizon import tables
 
@@ -41,7 +39,9 @@ class UpdateUsersLink(tables.LinkAction):
     verbose_name = _("Manage Members")
     url = "horizon:identity:domains:update"
     classes = ("ajax-modal",)
-    policy_rules = (("identity", "identity:update_domain"),)
+    policy_rules = (("identity", "identity:list_users"),
+                    ("identity", "identity:list_roles"),
+                    ("identity", "identity:list_role_assignments"))
 
     def get_link_url(self, domain):
         step = 'update_user_members'
@@ -56,7 +56,6 @@ class UpdateGroupsLink(tables.LinkAction):
     url = "horizon:identity:domains:update"
     classes = ("ajax-modal",)
     icon = "pencil"
-    policy_rules = (("identity", "identity:update_domain"),)
 
     def get_link_url(self, domain):
         step = 'update_group_members'
@@ -93,19 +92,20 @@ class DeleteDomainsAction(tables.DeleteAction):
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
-            "Delete Domain",
-            "Delete Domains",
+            u"Delete Domain",
+            u"Delete Domains",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ungettext_lazy(
-            "Deleted Domain",
-            "Deleted Domains",
+            u"Deleted Domain",
+            u"Deleted Domains",
             count
         )
 
+    name = "delete"
     policy_rules = (('identity', 'identity:delete_domain'),)
 
     def allowed(self, request, datum):
@@ -117,95 +117,17 @@ class DeleteDomainsAction(tables.DeleteAction):
             msg = _('Domain "%s" must be disabled before it can be deleted.') \
                 % domain.name
             messages.error(request, msg)
-            raise keystoneclient_exceptions.ClientException(msg)
-
-        LOG.info('Deleting domain "%s".', obj_id)
-        api.keystone.domain_delete(request, obj_id)
-
-
-class DisableDomainsAction(tables.BatchAction):
-    @staticmethod
-    def action_present(count):
-        return ungettext_lazy(
-            "Disable Domain",
-            "Disable Domains",
-            count
-        )
-
-    @staticmethod
-    def action_past(count):
-        return ungettext_lazy(
-            "Disabled Domain",
-            "Disabled Domains",
-            count
-        )
-
-    name = "disable"
-    policy_rules = (('identity', 'identity:update_domain'),)
-    verbose_name = _("Disable Domains")
-
-    def allowed(self, request, datum):
-        return api.keystone.keystone_can_edit_domain() \
-            and (datum is None or datum.enabled)
-
-    def action(self, request, obj_id):
-        domain = self.table.get_object_by_id(obj_id)
-        if domain.enabled:
-            LOG.info('Disabling domain "%s".', obj_id)
-            try:
-                api.keystone.domain_update(request,
-                                           domain_id=domain.id,
-                                           name=domain.name,
-                                           description=domain.description,
-                                           enabled=False)
-            except Exception:
-                exceptions.handle(request, ignore=True)
-                return False
-
-
-class EnableDomainsAction(tables.BatchAction):
-    @staticmethod
-    def action_present(count):
-        return ungettext_lazy(
-            "Enable Domain",
-            "Enable Domains",
-            count
-        )
-
-    @staticmethod
-    def action_past(count):
-        return ungettext_lazy(
-            "Enabled Domain",
-            "Enabled Domains",
-            count
-        )
-
-    name = "enable"
-    policy_rules = (('identity', 'identity:update_domain'),)
-    verbose_name = _("Enable Domains")
-
-    def allowed(self, request, datum):
-        return api.keystone.keystone_can_edit_domain() \
-            and (datum is None or not datum.enabled)
-
-    def action(self, request, obj_id):
-        domain = self.table.get_object_by_id(obj_id)
-        if not domain.enabled:
-            LOG.info('Enabling domain "%s".', obj_id)
-            try:
-                api.keystone.domain_update(request,
-                                           domain_id=domain.id,
-                                           name=domain.name,
-                                           description=domain.description,
-                                           enabled=True)
-            except Exception:
-                exceptions.handle(request, ignore=True)
-                return False
+            raise exceptions.ClientException(409, msg)
+        else:
+            LOG.info('Deleting domain "%s".' % obj_id)
+            api.keystone.domain_delete(request, obj_id)
 
 
 class DomainFilterAction(tables.FilterAction):
     def allowed(self, request, datum):
-        multidomain_support = settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT
+        multidomain_support = getattr(settings,
+                                      'OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT',
+                                      False)
         return multidomain_support
 
     def filter(self, table, domains, filter_string):
@@ -225,10 +147,12 @@ class SetDomainContext(tables.Action):
     verbose_name = _("Set Domain Context")
     url = constants.DOMAINS_INDEX_URL
     preempt = True
-    policy_rules = (('identity', 'identity:update_domain'),)
+    policy_rules = (('identity', 'admin_required'),)
 
     def allowed(self, request, datum):
-        multidomain_support = settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT
+        multidomain_support = getattr(settings,
+                                      'OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT',
+                                      False)
         if not multidomain_support:
             return False
 
@@ -247,11 +171,9 @@ class SetDomainContext(tables.Action):
                 messages.success(request,
                                  _('Domain Context updated to Domain %s.') %
                                  domain.name)
-                return shortcuts.redirect(request.get_full_path())
             except Exception:
                 messages.error(request,
                                _('Unable to set Domain Context.'))
-                return shortcuts.redirect(request.get_full_path())
 
 
 class UnsetDomainContext(tables.Action):
@@ -260,7 +182,7 @@ class UnsetDomainContext(tables.Action):
     url = constants.DOMAINS_INDEX_URL
     preempt = True
     requires_input = False
-    policy_rules = (('identity', 'identity:update_domain'),)
+    policy_rules = (('identity', 'admin_required'),)
 
     def allowed(self, request, datum):
         ctx = request.session.get("domain_context", None)
@@ -271,11 +193,10 @@ class UnsetDomainContext(tables.Action):
             request.session.pop("domain_context")
             request.session.pop("domain_context_name")
             messages.success(request, _('Domain Context cleared.'))
-            return shortcuts.redirect(request.get_full_path())
 
 
 class DomainsTable(tables.DataTable):
-    name = tables.WrappingColumn('name', verbose_name=_('Name'))
+    name = tables.Column('name', verbose_name=_('Name'))
     description = tables.Column(lambda obj: getattr(obj, 'description', None),
                                 verbose_name=_('Description'))
     id = tables.Column('id', verbose_name=_('Domain ID'))
@@ -285,9 +206,7 @@ class DomainsTable(tables.DataTable):
     class Meta(object):
         name = "domains"
         verbose_name = _("Domains")
-        table_actions_menu = (EnableDomainsAction, DisableDomainsAction)
         row_actions = (SetDomainContext, UpdateUsersLink, UpdateGroupsLink,
-                       EditDomainLink, EnableDomainsAction,
-                       DisableDomainsAction, DeleteDomainsAction)
+                       EditDomainLink, DeleteDomainsAction)
         table_actions = (DomainFilterAction, CreateDomainLink,
                          DeleteDomainsAction, UnsetDomainContext)
