@@ -11,8 +11,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: KC Wang, Big Switch Networks
 
 from mox import IsA  # noqa
 
@@ -51,40 +49,68 @@ class FirewallTests(test.TestCase):
     INSERTRULE_PATH = 'horizon:%s:firewalls:insertrule' % DASHBOARD
     REMOVERULE_PATH = 'horizon:%s:firewalls:removerule' % DASHBOARD
 
-    def set_up_expect(self):
+    ADDROUTER_PATH = 'horizon:%s:firewalls:addrouter' % DASHBOARD
+    REMOVEROUTER_PATH = 'horizon:%s:firewalls:removerouter' % DASHBOARD
+
+    def set_up_expect(self, fwaas_router_extension=True):
         # retrieve rules
         tenant_id = self.tenant.id
 
-        api.fwaas.rule_list(
+        api.neutron.is_extension_supported(
+            IsA(http.HttpRequest), 'fwaasrouterinsertion'
+        ).AndReturn(fwaas_router_extension)
+
+        api.neutron.is_extension_supported(
+            IsA(http.HttpRequest), 'fwaasrouterinsertion'
+        ).MultipleTimes().AndReturn(fwaas_router_extension)
+
+        api.fwaas.rule_list_for_tenant(
             IsA(http.HttpRequest),
-            tenant_id=tenant_id).AndReturn(self.fw_rules.list())
+            tenant_id).AndReturn(self.fw_rules.list())
 
         # retrieves policies
         policies = self.fw_policies.list()
-        api.fwaas.policy_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
+        api.fwaas.policy_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(policies)
 
         # retrieves firewalls
         firewalls = self.firewalls.list()
-        api.fwaas.firewall_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(firewalls)
+        api.fwaas.firewall_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(firewalls)
+
+        routers = self.routers.list()
+        api.neutron.router_list(
+            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(routers)
+
+        api.neutron.router_list(
+            IsA(http.HttpRequest), tenant_id=tenant_id). \
+            MultipleTimes().AndReturn(routers)
+
+        api.fwaas.firewall_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id='1'). \
+            MultipleTimes().AndReturn(firewalls)
 
     def set_up_expect_with_exception(self):
         tenant_id = self.tenant.id
 
-        api.fwaas.rule_list(
-            IsA(http.HttpRequest),
-            tenant_id=tenant_id).AndRaise(self.exceptions.neutron)
-        api.fwaas.policy_list(
-            IsA(http.HttpRequest),
-            tenant_id=tenant_id).AndRaise(self.exceptions.neutron)
-        api.fwaas.firewall_list(
-            IsA(http.HttpRequest),
-            tenant_id=tenant_id).AndRaise(self.exceptions.neutron)
+        api.neutron.is_extension_supported(
+            IsA(http.HttpRequest), 'fwaasrouterinsertion').AndReturn(True)
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list')}, )
+        api.fwaas.rule_list_for_tenant(
+            IsA(http.HttpRequest),
+            tenant_id).AndRaise(self.exceptions.neutron)
+        api.fwaas.policy_list_for_tenant(
+            IsA(http.HttpRequest),
+            tenant_id).AndRaise(self.exceptions.neutron)
+        api.fwaas.firewall_list_for_tenant(
+            IsA(http.HttpRequest),
+            tenant_id).AndRaise(self.exceptions.neutron)
+
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant'),
+                        api.neutron: ('is_extension_supported',
+                                      'router_list',), })
     def test_index_firewalls(self):
         self.set_up_expect()
 
@@ -100,9 +126,14 @@ class FirewallTests(test.TestCase):
         self.assertEqual(len(res.context['table'].data),
                          len(self.firewalls.list()))
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list')}, )
+    # TODO(absubram): Change test_index_firewalls for with and without
+    #                 router extensions.
+
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant'),
+                        api.neutron: ('is_extension_supported',
+                                      'router_list',), })
     def test_index_policies(self):
         self.set_up_expect()
 
@@ -119,9 +150,11 @@ class FirewallTests(test.TestCase):
         self.assertEqual(len(res.context['policiestable_table'].data),
                          len(self.fw_policies.list()))
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant'),
+                        api.neutron: ('is_extension_supported',
+                                      'router_list',), })
     def test_index_rules(self):
         self.set_up_expect()
 
@@ -138,9 +171,10 @@ class FirewallTests(test.TestCase):
         self.assertEqual(len(res.context['rulestable_table'].data),
                          len(self.fw_rules.list()))
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant'),
+                        api.neutron: ('is_extension_supported',), })
     def test_index_exception_firewalls(self):
         self.set_up_expect_with_exception()
 
@@ -157,9 +191,10 @@ class FirewallTests(test.TestCase):
                                 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['table'].data), 0)
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant'),
+                        api.neutron: ('is_extension_supported',), })
     def test_index_exception_policies(self):
         self.set_up_expect_with_exception()
 
@@ -177,9 +212,10 @@ class FirewallTests(test.TestCase):
                                 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['policiestable_table'].data), 0)
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant'),
+                        api.neutron: ('is_extension_supported',), })
     def test_index_exception_rules(self):
         self.set_up_expect_with_exception()
 
@@ -244,7 +280,8 @@ class FirewallTests(test.TestCase):
 
         self.assertFormErrors(res, 2)
 
-    @test.create_stubs({api.fwaas: ('policy_create', 'rule_list'), })
+    @test.create_stubs({api.fwaas: ('policy_create',
+                                    'rule_list_for_tenant'), })
     def test_add_policy_post(self):
         policy = self.fw_policies.first()
         rules = self.fw_rules.list()
@@ -270,8 +307,8 @@ class FirewallTests(test.TestCase):
         for rule in rules:
             if rule.id in policy.firewall_rules:
                 rule.firewall_policy_id = rule.policy = None
-        api.fwaas.rule_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
+        api.fwaas.rule_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(rules)
         api.fwaas.policy_create(
             IsA(http.HttpRequest), **form_data).AndReturn(policy)
 
@@ -282,7 +319,8 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('policy_create', 'rule_list'), })
+    @test.create_stubs({api.fwaas: ('policy_create',
+                                    'rule_list_for_tenant'), })
     def test_add_policy_post_with_error(self):
         policy = self.fw_policies.first()
         rules = self.fw_rules.list()
@@ -292,8 +330,8 @@ class FirewallTests(test.TestCase):
                      'shared': policy.shared,
                      'audited': policy.audited
                      }
-        api.fwaas.rule_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
+        api.fwaas.rule_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(rules)
 
         self.mox.ReplayAll()
 
@@ -301,19 +339,32 @@ class FirewallTests(test.TestCase):
 
         self.assertFormErrors(res, 1)
 
-    @test.create_stubs({api.fwaas: ('firewall_create', 'policy_list'), })
-    def test_add_firewall_post(self):
+    def _test_add_firewall_post(self, router_extension=False):
         firewall = self.firewalls.first()
         policies = self.fw_policies.list()
         tenant_id = self.tenant.id
+        if router_extension:
+            routers = self.routers.list()
+            firewalls = self.firewalls.list()
+
         form_data = {'name': firewall.name,
                      'description': firewall.description,
                      'firewall_policy_id': firewall.firewall_policy_id,
-                     'shared': firewall.shared,
                      'admin_state_up': firewall.admin_state_up
                      }
-        api.fwaas.policy_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
+        if router_extension:
+            form_data['router_ids'] = firewall.router_ids
+            api.neutron.router_list(
+                IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(routers)
+            api.fwaas.firewall_list_for_tenant(
+                IsA(http.HttpRequest),
+                tenant_id=tenant_id).AndReturn(firewalls)
+
+        api.neutron.is_extension_supported(
+            IsA(http.HttpRequest),
+            'fwaasrouterinsertion').AndReturn(router_extension)
+        api.fwaas.policy_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(policies)
         api.fwaas.firewall_create(
             IsA(http.HttpRequest), **form_data).AndReturn(firewall)
 
@@ -324,7 +375,26 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('firewall_create', 'policy_list'), })
+    @test.create_stubs({api.fwaas: ('firewall_create',
+                                    'policy_list_for_tenant',),
+                        api.neutron: ('is_extension_supported',), })
+    def test_add_firewall_post(self):
+        self._test_add_firewall_post()
+
+    # @test.create_stubs({api.fwaas: ('firewall_create',
+    #                                'policy_list_for_tenant',
+    #                                'firewall_list_for_tenant',),
+    #                    api.neutron: ('is_extension_supported',
+    #                                  'router_list'), })
+    # def test_add_firewall_post_with_router_extension(self):
+    #    self._test_add_firewall_post(router_extension=True)
+    # TODO(absubram): Fix test_add_firewall_post_with_router_extension
+    #                 It currently fails because views.py is not
+    #                 initializing the AddRouter workflow?
+
+    @test.create_stubs({api.fwaas: ('firewall_create',
+                                    'policy_list_for_tenant',),
+                        api.neutron: ('is_extension_supported',), })
     def test_add_firewall_post_with_error(self):
         firewall = self.firewalls.first()
         policies = self.fw_policies.list()
@@ -332,11 +402,13 @@ class FirewallTests(test.TestCase):
         form_data = {'name': firewall.name,
                      'description': firewall.description,
                      'firewall_policy_id': None,
-                     'shared': firewall.shared,
                      'admin_state_up': firewall.admin_state_up
                      }
-        api.fwaas.policy_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
+        api.neutron.is_extension_supported(
+            IsA(http.HttpRequest),
+            'fwaasrouterinsertion').AndReturn(False)
+        api.fwaas.policy_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(policies)
 
         self.mox.ReplayAll()
 
@@ -471,7 +543,7 @@ class FirewallTests(test.TestCase):
         self.assertTemplateUsed(res, 'project/firewalls/updatepolicy.html')
 
     @test.create_stubs({api.fwaas: ('policy_get', 'policy_update',
-                                    'rule_list')})
+                                    'rule_list_for_tenant')})
     def test_update_policy_post(self):
         policy = self.fw_policies.first()
 
@@ -495,14 +567,14 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('firewall_get', 'policy_list')})
+    @test.create_stubs({api.fwaas: ('firewall_get', 'policy_list_for_tenant')})
     def test_update_firewall_get(self):
         firewall = self.firewalls.first()
         policies = self.fw_policies.list()
         tenant_id = self.tenant.id
 
-        api.fwaas.policy_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
+        api.fwaas.policy_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(policies)
 
         api.fwaas.firewall_get(IsA(http.HttpRequest),
                                firewall.id).AndReturn(firewall)
@@ -514,7 +586,7 @@ class FirewallTests(test.TestCase):
 
         self.assertTemplateUsed(res, 'project/firewalls/updatefirewall.html')
 
-    @test.create_stubs({api.fwaas: ('firewall_get', 'policy_list',
+    @test.create_stubs({api.fwaas: ('firewall_get', 'policy_list_for_tenant',
                                     'firewall_update')})
     def test_update_firewall_post(self):
         firewall = self.firewalls.first()
@@ -529,8 +601,8 @@ class FirewallTests(test.TestCase):
                 }
 
         policies = self.fw_policies.list()
-        api.fwaas.policy_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
+        api.fwaas.policy_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(policies)
 
         api.fwaas.firewall_update(IsA(http.HttpRequest), firewall.id, **data)\
             .AndReturn(firewall)
@@ -544,7 +616,7 @@ class FirewallTests(test.TestCase):
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
     @test.create_stubs({api.fwaas: ('policy_get', 'policy_insert_rule',
-                                    'rule_list', 'rule_get')})
+                                    'rule_list_for_tenant', 'rule_get')})
     def test_policy_insert_rule(self):
         policy = self.fw_policies.first()
         tenant_id = self.tenant.id
@@ -563,8 +635,8 @@ class FirewallTests(test.TestCase):
                                  new_rule_id,
                                  rules[1].id]
 
-        api.fwaas.rule_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
+        api.fwaas.rule_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(rules)
         api.fwaas.rule_get(
             IsA(http.HttpRequest), new_rule_id).AndReturn(rules[2])
         api.fwaas.policy_insert_rule(IsA(http.HttpRequest), policy.id, **data)\
@@ -579,7 +651,7 @@ class FirewallTests(test.TestCase):
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
     @test.create_stubs({api.fwaas: ('policy_get', 'policy_remove_rule',
-                                    'rule_list', 'rule_get')})
+                                    'rule_list_for_tenant', 'rule_get')})
     def test_policy_remove_rule(self):
         policy = self.fw_policies.first()
         tenant_id = self.tenant.id
@@ -601,8 +673,8 @@ class FirewallTests(test.TestCase):
 
         api.fwaas.policy_get(IsA(http.HttpRequest),
                              policy.id).AndReturn(policy)
-        api.fwaas.rule_list(
-            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
+        api.fwaas.rule_list_for_tenant(
+            IsA(http.HttpRequest), tenant_id).AndReturn(rules)
         api.fwaas.rule_get(
             IsA(http.HttpRequest), remove_rule_id).AndReturn(rules[0])
         api.fwaas.policy_remove_rule(IsA(http.HttpRequest), policy.id, **data)\
@@ -616,10 +688,75 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list',
-                                    'rule_delete')})
+    @test.create_stubs({api.fwaas: ('firewall_get',
+                                    'firewall_list_for_tenant',
+                                    'firewall_update',
+                                    'firewall_unassociated_routers_list')})
+    def test_firewall_add_router(self):
+        tenant_id = self.tenant.id
+        firewall = self.firewalls.first()
+        routers = self.routers.list()
+
+        existing_router_ids = firewall.router_ids
+        add_router_ids = [routers[1].id]
+
+        form_data = {'router_ids': add_router_ids}
+        post_data = {'router_ids': add_router_ids + existing_router_ids}
+
+        api.fwaas.firewall_get(
+            IsA(http.HttpRequest), firewall.id).AndReturn(firewall)
+        api.fwaas.firewall_unassociated_routers_list(
+            IsA(http.HttpRequest), tenant_id).AndReturn(routers)
+
+        firewall.router_ids = [add_router_ids, existing_router_ids]
+
+        api.fwaas.firewall_update(
+            IsA(http.HttpRequest),
+            firewall.id, **post_data).AndReturn(firewall)
+
+        self.mox.ReplayAll()
+
+        res = self.client.post(
+            reverse(self.ADDROUTER_PATH, args=(firewall.id,)), form_data)
+
+        self.assertNoFormErrors(res)
+        self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
+
+    @test.create_stubs({api.fwaas: ('firewall_get',
+                                    'firewall_update',
+                                    'firewall_unassociated_routers_list'),
+                        api.neutron: ('router_list',), })
+    def test_firewall_remove_router(self):
+        firewall = self.firewalls.first()
+        tenant_id = self.tenant.id
+        routers = self.routers.list()
+        existing_router_ids = firewall.router_ids
+
+        form_data = {'router_ids': existing_router_ids}
+
+        api.fwaas.firewall_get(
+            IsA(http.HttpRequest), firewall.id).AndReturn(firewall)
+        api.neutron.router_list(
+            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(routers)
+        firewall.router_ids = []
+        api.fwaas.firewall_update(
+            IsA(http.HttpRequest),
+            firewall.id, **form_data).AndReturn(firewall)
+
+        self.mox.ReplayAll()
+
+        res = self.client.post(
+            reverse(self.REMOVEROUTER_PATH, args=(firewall.id,)), form_data)
+
+        self.assertNoFormErrors(res)
+        self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
+
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant',
+                                    'rule_delete'),
+                        api.neutron: ('is_extension_supported',
+                                      'router_list',), })
     def test_delete_rule(self):
         self.set_up_expect()
         rule = self.fw_rules.first()
@@ -631,10 +768,12 @@ class FirewallTests(test.TestCase):
 
         self.assertNoFormErrors(res)
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list',
-                                    'policy_delete')})
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant',
+                                    'policy_delete'),
+                        api.neutron: ('is_extension_supported',
+                                      'router_list',), })
     def test_delete_policy(self):
         self.set_up_expect()
         policy = self.fw_policies.first()
@@ -646,10 +785,12 @@ class FirewallTests(test.TestCase):
 
         self.assertNoFormErrors(res)
 
-    @test.create_stubs({api.fwaas: ('firewall_list',
-                                    'policy_list',
-                                    'rule_list',
-                                    'firewall_delete')})
+    @test.create_stubs({api.fwaas: ('firewall_list_for_tenant',
+                                    'policy_list_for_tenant',
+                                    'rule_list_for_tenant',
+                                    'firewall_delete'),
+                        api.neutron: ('is_extension_supported',
+                                      'router_list',), })
     def test_delete_firewall(self):
         self.set_up_expect()
         fwl = self.firewalls.first()
