@@ -17,6 +17,7 @@
 Views for managing Neutron Routers.
 """
 
+from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
 from django.utils.datastructures import SortedDict
 from django.utils.translation import pgettext_lazy
@@ -38,6 +39,7 @@ from openstack_dashboard.dashboards.project.routers import tabs as rdtabs
 class IndexView(tables.DataTableView):
     table_class = rtables.RoutersTable
     template_name = 'project/routers/index.html'
+    page_title = _("Routers")
 
     def _get_routers(self, search_opts=None):
         try:
@@ -53,7 +55,7 @@ class IndexView(tables.DataTableView):
         ext_net_dict = self._list_external_networks()
 
         for r in routers:
-            r.set_id_as_name_if_empty()
+            r.name = r.name_or_id
             self._set_external_network(r, ext_net_dict)
         return routers
 
@@ -66,9 +68,8 @@ class IndexView(tables.DataTableView):
             search_opts = {'router:external': True}
             ext_nets = api.neutron.network_list(self.request,
                                                 **search_opts)
-            for ext_net in ext_nets:
-                ext_net.set_id_as_name_if_empty()
-            ext_net_dict = SortedDict((n['id'], n.name) for n in ext_nets)
+            ext_net_dict = SortedDict((n['id'], n.name_or_id)
+                                      for n in ext_nets)
         except Exception as e:
             msg = _('Unable to retrieve a list of external networks "%s".') % e
             exceptions.handle(self.request, msg)
@@ -98,6 +99,7 @@ class DetailView(tabs.TabbedTableView):
     tab_group_class = rdtabs.RouterDetailTabs
     template_name = 'project/routers/detail.html'
     failure_url = reverse_lazy('horizon:project:routers:index')
+    page_title = _("Router Details")
 
     @memoized.memoized_method
     def _get_data(self):
@@ -123,35 +125,65 @@ class DetailView(tabs.TabbedTableView):
                 router.external_gateway_info['network'] = ext_net_id
         return router
 
+    @memoized.memoized_method
+    def _get_ports(self):
+        try:
+            ports = api.neutron.port_list(self.request,
+                                          device_id=self.kwargs['router_id'])
+        except Exception:
+            ports = []
+            msg = _('Unable to retrieve port details.')
+            exceptions.handle(self.request, msg)
+        return ports
+
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
-        context["router"] = self._get_data()
+        router = self._get_data()
+        table = rtables.RoutersTable(self.request)
+
+        context["router"] = router
+        context["url"] = self.failure_url
+        context["actions"] = table.render_row_actions(router)
         context['dvr_supported'] = api.neutron.get_feature_permission(
             self.request, "dvr", "get")
         context['ha_supported'] = api.neutron.get_feature_permission(
             self.request, "l3-ha", "get")
+
         return context
 
-    def get(self, request, *args, **kwargs):
+    def get_tabs(self, request, *args, **kwargs):
         router = self._get_data()
-        self.kwargs['router'] = router
-        return super(DetailView, self).get(request, *args, **kwargs)
+        ports = self._get_ports()
+        return self.tab_group_class(request, router=router,
+                                    ports=ports, **kwargs)
 
 
 class CreateView(forms.ModalFormView):
     form_class = project_forms.CreateForm
+    form_id = "create_router_form"
+    modal_header = _("Create Router")
     template_name = 'project/routers/create.html'
     success_url = reverse_lazy("horizon:project:routers:index")
+    page_title = _("Create Router")
+    submit_label = _("Create Router")
+    submit_url = reverse_lazy("horizon:project:routers:create")
 
 
 class UpdateView(forms.ModalFormView):
     form_class = project_forms.UpdateForm
+    form_id = "update_router_form"
+    modal_header = _("Edit Router")
     template_name = 'project/routers/update.html'
     success_url = reverse_lazy("horizon:project:routers:index")
+    page_title = _("Update Router")
+    submit_label = _("Save Changes")
+    submit_url = "horizon:project:routers:update"
 
     def get_context_data(self, **kwargs):
         context = super(UpdateView, self).get_context_data(**kwargs)
+        args = (self.kwargs['router_id'],)
         context["router_id"] = self.kwargs['router_id']
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def _get_object(self, *args, **kwargs):
