@@ -11,8 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Tatiana Mazur
+
+import logging
 
 from django.utils.translation import ugettext_lazy as _
 
@@ -21,21 +21,29 @@ import horizon
 from openstack_dashboard.api import neutron
 from openstack_dashboard.dashboards.project import dashboard
 
+LOG = logging.getLogger(__name__)
+
 
 class VPN(horizon.Panel):
     name = _("VPN")
     slug = 'vpn'
     permissions = ('openstack.services.network',)
 
-    def can_access(self, context):
+    def allowed(self, context):
         request = context['request']
         if not request.user.has_perms(self.permissions):
             return False
-        if not neutron.is_service_enabled(request,
-                                          config_name='enable_vpn',
-                                          ext_name='vpnaas'):
+        try:
+            if not neutron.is_service_enabled(request,
+                                              config_name='enable_vpn',
+                                              ext_name='vpnaas'):
+                return False
+        except Exception:
+            LOG.error("Call to list enabled services failed. This is likely "
+                      "due to a problem communicating with the Neutron "
+                      "endpoint. VPN panel will not be displayed.")
             return False
-        if not super(VPN, self).can_access(context):
+        if not super(VPN, self).allowed(context):
             return False
         return True
 
