@@ -42,7 +42,6 @@ class KeystoneRestTestCase(test.TestCase):
         self.assertStatusCode(response, 200)
         self.assertEqual(response.content, '{"name": "Ni!"}')
         kc.user_get.assert_called_once_with(request, 'current_id')
-        kc.user_get.assert_not_called()
 
     @mock.patch.object(keystone.api, 'keystone')
     def test_user_get_list(self, kc):
@@ -151,7 +150,7 @@ class KeystoneRestTestCase(test.TestCase):
         response = keystone.Users().delete(request)
         self.assertStatusCode(response, 204)
         self.assertEqual(response.content, '')
-        kc.user_delete.assert_has_mock.calls([
+        kc.user_delete.assert_has_calls([
             mock.call(request, 'id1'),
             mock.call(request, 'id2'),
             mock.call(request, 'id3'),
@@ -312,7 +311,7 @@ class KeystoneRestTestCase(test.TestCase):
         response = keystone.Roles().delete(request)
         self.assertStatusCode(response, 204)
         self.assertEqual(response.content, '')
-        kc.role_delete.assert_has_mock.calls([
+        kc.role_delete.assert_has_calls([
             mock.call(request, 'id1'),
             mock.call(request, 'id2'),
             mock.call(request, 'id3'),
@@ -418,7 +417,7 @@ class KeystoneRestTestCase(test.TestCase):
         response = keystone.Domains().delete(request)
         self.assertStatusCode(response, 204)
         self.assertEqual(response.content, '')
-        kc.domain_delete.assert_has_mock.calls([
+        kc.domain_delete.assert_has_calls([
             mock.call(request, 'id1'),
             mock.call(request, 'id2'),
             mock.call(request, 'id3'),
@@ -539,7 +538,7 @@ class KeystoneRestTestCase(test.TestCase):
         response = keystone.Projects().delete(request)
         self.assertStatusCode(response, 204)
         self.assertEqual(response.content, '')
-        kc.tenant_delete.assert_has_mock.calls([
+        kc.tenant_delete.assert_has_calls([
             mock.call(request, 'id1'),
             mock.call(request, 'id2'),
             mock.call(request, 'id3'),
